jinja2: General purpose template engine for Python
==================================================

Description
-----------

Jinja2 is a library for Python 2.4 and onwards that is designed to be
flexible, fast and secure.

If you have any exposure to other text-based template languages, such as
Smarty or Django, you should feel right at home with Jinja2. It's both
designer and developer friendly by sticking to Python's principles and
adding functionality useful for templating environments.

License
-------

Modified BSD License


Upstream Contact
----------------

Author: Pocoo Team <http://pocoo.org>

Homepage: http://jinja.pocoo.org/

Dependencies
------------

-  Python (>= 2.4)
-  setuptools (or distribute)
-  Pygments (according to 'spkg/standard/deps')
-  docutils (dito, as a note only)


Special Update/Build Instructions
---------------------------------

None. (Just make sure its prerequisites are new enough in Sage, to avoid
downloads during the build / installation.)
